@@ -1,33 +1,168 @@
-#' Method to get the sojourn time distribution f
-#' 
-#' @description Computes the conditional sojourn time distribution \eqn{f(k)}, 
-#'   \eqn{f_{i}(k)}, \eqn{f_{j}(k)} or \eqn{f_{ij}(k)}.
-#'   
-#' @param x An object of S3 class `smmfit` or `smm`.
-#' @param k A positive integer giving the time horizon.
-#' @return A vector, matrix or array giving the value of \eqn{f} at each time 
-#'   between 0 and `k`.
-#'   
-#' @noRd
-#' 
+# Method to get the conditional sojourn time distribution f
 .get.f <- function(x, k) {
   UseMethod(".get.f", x)
 }
 
 
-#' Method to get the number of parameters of the semi-Markov chain
+#' Method to get the conditional sojourn time distribution f
 #' 
-#' @description Method to get the number of parameters of the semi-Markov 
-#'   chain. This method is useful for the computation of criteria such as AIC 
-#'   and BIC.
+#' @description Computes the conditional sojourn time distribution \eqn{f(k)}, 
+#'   \eqn{f_{i}(k)}, \eqn{f_{j}(k)} or \eqn{f_{ij}(k)}.
+#'   
+#' @param x An object of S3 class `smmfit` or `smm`.
+#' @param k A strictly positive integer giving the time horizon (k must be 
+#'   different from 0 since we assume that there are not instantaneous 
+#'   transitions).
+#' @return A vector, matrix or array giving the value of \eqn{f} at each time 
+#'   between 1 and `k`.
+#'   
+#' @export
 #' 
-#' @param x An object for which the number of parameters can be returned.
+get.f <- function(x, k) {
+  UseMethod("get.f", x)
+}
+
+
+# Method to get the number of parameters of the semi-Markov chain
+.get.Kpar <- function(x) {
+  UseMethod(".get.Kpar", x)
+}
+
+
+#' Method to get the number of parameters of a Markov or semi-Markov chain
+#' 
+#' @description Method to get the number of parameters of a Markov or 
+#'   such as AIC and BIC.
+#' 
+#' @param x An object for which the number of parameters can be returned (An 
+#'   object of class `smm` or `mm`).
 #' @return A positive integer giving the number of parameters.
 #' 
-#' @noRd
+#' @export
 #' 
-.getKpar <- function(x) {
-  UseMethod(".getKpar", x)
+get.Kpar <- function(x) {
+  UseMethod("get.Kpar", x)
+}
+
+
+#' Method to get the limit (stationary) distribution
+#' 
+#' @description Method to get the limit (stationary) distribution of a
+#'   semi-Markov chain.
+#' 
+#' @param x An object of S3 class `smmfit` or `smm`.
+#' @param klim Optional. The time horizon used to approximate the series in the 
+#'   computation of the mean sojourn times vector \eqn{m} (cf. 
+#'   [meanSojournTimes][meanSojournTimes] function).
+#' @return A vector of length \eqn{\textrm{card}(E)} giving the values of the 
+#'   limit distribution.
+#' 
+#' @export
+#' 
+get.limitDistribution <- function(x, klim = 10000) {
+  UseMethod("get.limitDistribution", x)
+}
+
+
+#' Method to get the stationary distribution
+#' 
+#' @description Method to get the stationary distribution of a Markov chain.
+#'   If the order of the Markov chain is higher than one, a block matrix is
+#'   computed to get the stationary distribution.
+#' 
+#' @param x An object of S3 class `mm` or `mmfit`.
+#' @return A vector of length \eqn{\textrm{card}(E)} giving the values of the 
+#'   stationary distribution.
+#' 
+#' @export
+#' 
+get.stationaryDistribution <- function(x) {
+  UseMethod("get.stationaryDistribution", x)
+}
+
+
+# Method to get the semi-Markov kernel \eqn{q_{Y}}
+.get.qy <- function(x, k, upstates = x$states) {
+  UseMethod(".get.qy", x)
+}
+
+
+#' Method to get the semi-Markov kernel \eqn{q_{Y}}
+#' 
+#' @description Computes the semi-Markov kernel \eqn{q_{Y}(k)}
+#'   (See proposition 5.1 p.106).
+#' 
+#' @param x An object of S3 class `smmfit` or `smm`.
+#' @param k A positive integer giving the time horizon.
+#' @param upstates Vector giving the subset of operational states \eqn{U}.
+#' @return An array giving the value of \eqn{q_{Y}(k)} at each time between 0 
+#'   and `k`.
+#' 
+#' @export
+#' 
+get.qy <- function(x, k, upstates = x$states) {
+  UseMethod("get.qy", x)
+}
+
+
+# Method to compute the value of \eqn{P}
+.get.P <- function(x, k, states = x$states, var = FALSE, klim = 10000) {
+  UseMethod(".get.P", x)
+}
+
+
+#' Method to compute the value of \eqn{P}
+#' 
+#' @description Method to compute the value of \eqn{P} 
+#'   (See equation (3.33) p.59).
+#' 
+#' @param x An object of S3 class `smmfit` or `smm`.
+#' @param k A positive integer giving the time horizon.
+#' @param states Vector giving the states for which the mean sojourn time 
+#'   should be computed. `states` is a subset of \eqn{E}.
+#' @param var Logical. If `TRUE` the asymptotic variance is computed.
+#' @param klim Optional. The time horizon used to approximate the series in the 
+#'   computation of the mean sojourn times vector \eqn{m} (cf. 
+#'   [meanSojournTimes][meanSojournTimes] function) for the asymptotic 
+#'   variance.
+#' @return An array giving the value of \eqn{P_{i,j}(k)} at each time between 0
+#'   and `k` if `var = FALSE`. If `var = TRUE`, a list containing the 
+#'   following components:
+#'   \describe{
+#'    \item{x: }{an array giving the value of \eqn{P_{ij}(k)} at each time 
+#'      between 0 and `k`;}
+#'    \item{sigma2: }{an array giving the asymptotic variance of the estimator 
+#'      \eqn{\sigma_{P}^{2}(i, j, k)}.}
+#'  }
+#'  
+#' @export
+#' 
+get.P <- function(x, k, states = x$states, var = FALSE, klim = 10000) {
+  UseMethod("get.P", x)
+}
+
+
+# Method to compute the value of \eqn{P}
+.get.Py <- function(x, k, upstates = x$states) {
+  UseMethod(".get.Py", x)
+}
+
+
+#' Method to compute the value of \eqn{P_{Y}}
+#' 
+#' @description Method to compute the value of \eqn{P_{Y}}
+#'   (See Proposition 5.1 p.105-106).
+#' 
+#' @param x An object of S3 class `smmfit` or `smm`.
+#' @param k A positive integer giving the time horizon.
+#' @param upstates Vector giving the subset of operational states \eqn{U}.
+#' @return An array giving the value of \eqn{P_{Y}(k)} at each time between 0
+#'   and `k`.
+#' 
+#' @export
+#' 
+get.Py <- function(x, k, upstates = x$states) {
+  UseMethod("get.Py", x)
 }
 
 
@@ -40,47 +175,10 @@
 #' 
 #' @noRd
 #' 
-.loglik <- function(x, processes) {
-  UseMethod(".loglik", x)
+.logLik <- function(x, processes) {
+  UseMethod(".logLik", x)
 }
 
-
-#' Akaike Information Criterion (AIC)
-#' 
-#' @description Generic function computing the Akaike Information Criterion of 
-#'   the model `x`, with the list of sequences `sequences`.
-#' 
-#' @param x An object for which there exists a `loglik` attribute if 
-#'   `sequences = NULL` or a `loglik` method otherwise.
-#' @param sequences Optional. A list of vectors representing the sequences for 
-#'   which the AIC will be computed based on `x` using the method `loglik`.
-#' @return Value of the AIC.
-#' 
-#' @export
-#' 
-aic <- function(x, sequences = NULL) {
-  UseMethod("aic", x)
-}
-
-
-#' Bayesian Information Criterion (BIC)
-#' 
-#' @description Generic function computing the Bayesian Information Criterion 
-#'   of the model `x`, with the list of sequences `sequences`.
-#' 
-#' @param x An object for which there exists a `loglik` attribute if 
-#'   `sequences = NULL` or a `loglik` method otherwise.
-#' @param sequences Optional. A list of vectors representing the sequences for 
-#'   which the AIC will be computed based on `x` using the method `loglik`.
-#' @return Value of the BIC.
-#' 
-#' @export
-#' 
-bic <- function(x, sequences = NULL) {
-  UseMethod("bic", x)
-}
-
-
 #' Method to get the semi-Markov kernel \eqn{q}
 #' 
 #' @description Computes the semi-Markov kernel \eqn{q_{ij}(k)}.
@@ -94,7 +192,7 @@ bic <- function(x, sequences = NULL) {
 #' @return An array giving the value of \eqn{q_{ij}(k)} at each time between 0 
 #'   and `k` if `var = FALSE`. If `var = TRUE`, a list containing the 
 #'   following components:
-#'   \itemize{
+#'   \describe{
 #'    \item{x: }{an array giving the value of \eqn{q_{ij}(k)} at each time 
 #'      between 0 and `k`;}
 #'    \item{sigma2: }{an array giving the asymptotic variance of the estimator 
@@ -107,26 +205,6 @@ getKernel <- function(x, k, var = FALSE, klim = 10000) {
   UseMethod("getKernel", x)
 }
 
-
-#' Log-likelihood Function
-#' 
-#' @description Generic function computing the log-likelihood of the model `x`,
-#'   with the list of sequences `sequences`.
-#' 
-#' @param x An object for which there exists a `loglik` attribute if 
-#'   `sequences = NULL`. Otherwise, the log-likelihood will be computed using 
-#'   the model `x` and the sequences `sequences`.
-#' @param sequences Optional. A list of vectors representing the sequences for 
-#'   which the log-likelihood will be computed based on `x`.
-#' @return Value of the log-likelihood.
-#' 
-#' @export
-#' 
-loglik <- function(x, sequences = NULL) {
-  UseMethod("loglik", x)
-}
-
-
 #' Mean Sojourn Times Function
 #' 
 #' @description The mean sojourn time is the mean time spent in each state.
@@ -487,8 +565,6 @@ availability <- function(x, k, upstates = x$states, level = 0.95, klim = 10000)
 #'   the BMP-failure rate, variances, lower and upper asymptotic confidence 
 #'   limits (if `x` is an object of class `smmfit`).
 #'  
-#' @noRd
-#' 
 .failureRateBMP <- function(x, k, upstates = x$states, level = 0.95, epsilon = 1e-3, klim = 10000) {
   UseMethod(".failureRateBMP", x)
 }
@@ -509,12 +585,12 @@ availability <- function(x, k, upstates = x$states, level = 0.95, klim = 10000)
 #'   for \eqn{R(k) \neq 0}. If \eqn{R(k) = 0}, we set \eqn{r(k) := 0}.
 #'   
 #'   Note that the RG-failure rate is related to the BMP-failure rate 
-#'   (see [failureRateBMP] function) by:
+#'   (see [dot-failureRateBMP] function) by:
 #'   
 #'   \deqn{r(k) = - \ln (1 - \lambda(k)),\ k \in N}
 #'   
-#'   The computation of the RG-failure rate is based on the [failureRateBMP] 
-#'   function (See [failureRateBMP] for details about the parameter `epsilon`).
+#'   The computation of the RG-failure rate is based on the [dot-failureRateBMP] 
+#'   function (See [dot-failureRateBMP] for details about the parameter `epsilon`).
 #'   
 #' @param x An object of S3 class `smmfit` or `smm`.
 #' @param k A positive integer giving the period \eqn{[0, k]} on which the 
