@@ -22,6 +22,10 @@
 #' 
 #' # Specify a Markov model of order 1
 #' markov <- mm(states = states, init = init, ptrans = p, k = k)
+#'
+#' @testexamples
+#' expect_true(all(markov$param == p))
+#' expect_true(all(markov$init == init))
 #' 
 mm <- function(states, init, ptrans, k = 1) {
   
@@ -109,9 +113,19 @@ is.mm <- function(x) {
 }
 
 
+# Method to get the stationary distribution
+#' @export
+get.stationaryDistribution.mm <- function(x) {
+  
+  p <- .stationaryDistribution(ptrans = .blockMatrix(ptrans = x$ptrans))
+  
+  return(p)
+}
+
+
 # Method to get the number of parameters
 # (useful for the computation of criteria such as AIC and BIC)
-.getKpar.mm <- function(x) {
+.get.Kpar.mm <- function(x) {
   
   s <- x$s
   
@@ -121,6 +135,17 @@ is.mm <- function(x) {
 }
 
 
+# Method to get the number of parameters
+# (useful for the computation of criteria such as AIC and BIC)
+#' @export
+get.Kpar.mm <- function(x) {
+  
+  kpar <- .get.Kpar.mm(x)
+  
+  return(kpar)
+}
+
+
 #' Log-likelihood Function
 #' 
 #' @description Computation of the log-likelihood for a Markov model
@@ -130,7 +155,7 @@ is.mm <- function(x) {
 #' 
 #' @noRd
 #' 
-.loglik.mm <- function(x, processes) {
+.logLik.mm <- function(x, processes) {
   
   #############################
   # Let's compute the log-likelihood
@@ -142,9 +167,9 @@ is.mm <- function(x) {
   Nij <- processes$Nij
   maskNij <- processes$Nij != 0 & x$ptrans != 0
   
-  loglik <- sum(Nstarti[maskNstarti] * log(x$init[maskNstarti])) + sum(Nij[maskNij] * log(x$ptrans[maskNij]))
+  logLik <- sum(Nstarti[maskNstarti] * log(x$init[maskNstarti])) + sum(Nij[maskNij] * log(x$ptrans[maskNij]))
   
-  return(loglik)
+  return(logLik)
   
 }
 
@@ -162,15 +187,16 @@ is.mm <- function(x) {
 #' 
 #' @export
 #' 
-aic.mm <- function(x, sequences) {
+AIC.mm <- function(object, ...) {
   
-  loglik <- loglik(x, sequences)
+  sequences = list(...)[1]
+  logLik <- logLik(object, sequences)
   
-  kpar <- .getKpar(x)
+  kpar <- .get.Kpar(object)
   
-  aic <- -2 * loglik + 2 * kpar
+  AIC <- -2 * logLik + 2 * kpar
   
-  return(aic)
+  return(AIC)
   
 }
 
@@ -188,17 +214,18 @@ aic.mm <- function(x, sequences) {
 #' 
 #' @export
 #' 
-bic.mm <- function(x, sequences) {
+BIC.mm <- function(object, ...) {
   
-  loglik <- loglik(x, sequences)
+  sequences = list(...)[1]
+  logLik <- logLik(object, sequences)
   
-  kpar <- .getKpar(x)
+  kpar <- .get.Kpar(object)
   
   n <- sum(sapply(sequences, length))
   
-  bic <- -2 * loglik + log(n) * kpar
+  BIC <- -2 * logLik + log(n) * kpar
   
-  return(bic)
+  return(BIC)
 }
 
 
@@ -215,7 +242,9 @@ bic.mm <- function(x, sequences) {
 #' 
 #' @export
 #' 
-loglik.mm <- function(x, sequences) {
+logLik.mm <- function(object, ...) {
+
+  sequences = list(...)[1]
   
   #############################
   # Checking parameters sequences and states
@@ -225,15 +254,15 @@ loglik.mm <- function(x, sequences) {
     stop("The parameter 'sequences' should be a list of vectors")
   }
   
-  if (!all(unique(unlist(sequences)) %in% x$states)) {
+  if (!all(unique(unlist(sequences)) %in% object$states)) {
     stop("Some states in the list of observed sequences 'sequences' 
-         are not in the state space given by the model 'x'")
+         are not in the state space given by the model 'object'")
   }
   
-  processes <- processesMarkov(sequences = sequences, states = x$states, k = x$k, verbose = FALSE)
-  loglik <- .loglik.mm(x = x, processes = processes)
+  processes <- processesMarkov(sequences = sequences, states = object$states, k = object$k, verbose = FALSE)
+  logLik <- .logLik.mm(x = object, processes = processes)
   
-  return(loglik)
+  return(logLik)
   
 }
 
@@ -270,7 +299,12 @@ loglik.mm <- function(x, sequences) {
 #' markov <- mm(states = states, init = init, ptrans = p, k = k)
 #' 
 #' seqs <- simulate(object = markov, nsim = c(1000, 10000, 2000), seed = 150)
-#' 
+#'
+#' @testexamples
+#' expect_equal(length(seqs), 3)
+#' expect_equal(sapply(seqs, length), c(1000, 10000, 2000))
+#' expect_equal(seqs[[1]][995:1000], c("g","c","a","c","a","t"))
+#'
 simulate.mm <- function(object, nsim = 1, seed = NULL, ...) {
   
   #############################
@@ -285,12 +319,13 @@ simulate.mm <- function(object, nsim = 1, seed = NULL, ...) {
   # Checking parameter seed
   #############################
   
-  if (is.null(seed)) {
-    seed <- round(as.numeric(Sys.time()))
-  }
-  
-  if (!all(is.numeric(seed), seed >= 0, (seed %% 1) == 0)) {
-    stop("'seed' must be a positive integer")
+  if (!is.null(seed)) {
+    if (!all(is.numeric(seed), seed >= 0, (seed %% 1) == 0)) {
+      stop("'seed' must be a positive integer")
+    }
+    {
+      set.seed(seed)
+    }
   }
   
   
