@@ -13,20 +13,18 @@ is.smm <- function(x) {
 }
 
 
-#' Method to get the semi-Markov kernel \eqn{q_{Y}}
-#' 
-#' @description Computes the semi-Markov kernel \eqn{q_{Y}(k)}
-#'   (See proposition 5.1 p.106).
-#' 
-#' @param x An object of class `smm`.
-#' @param k A positive integer giving the time horizon.
-#' @param upstates Vector giving the subset of operational states \eqn{U}.
-#' @return An array giving the value of \eqn{q_{Y}(k)} at each time between 0 
-#'   and `k`.
-#' 
-#' @noRd
-#' 
-.get.qy <- function(x, k, upstates = x$upstates) {
+# Method to get the limit (stationary) distribution
+#' @export
+get.limitDistribution.smm <- function(x, klim = 10000) {
+  
+  p <- .limitDistribution(q = getKernel(x, k = klim), ptrans = x$ptrans)
+  
+  return(p)
+}
+
+
+# Method to get the semi-Markov kernel \eqn{q_{Y}}
+.get.qy <- function(x, k, upstates = x$states) {
   
   u <- length(upstates)
   
@@ -49,96 +47,42 @@ is.smm <- function(x) {
 }
 
 
-#' Method to compute the value of \eqn{H}
-#' 
-#' @description Method to compute the value of \eqn{H} (See equation (3.4) p.46).
-#' 
-#' @param q An array giving the values of the kernel for a giving time horizon 
-#'   \eqn{[0, \dots, k]} (This kernel `q` is the output of the method `getKernel` 
-#'   or `.get.qy`).
-#' @return An array giving the value of \eqn{H(k)} at each time between 0 
-#'   and `k`.
-#' 
-#' @noRd
-#' 
-.get.H <- function(q) {
+# Method to get the semi-Markov kernel \eqn{q_{Y}}
+#' @export
+get.qy <- function(x, k, upstates = x$states) {
   
-  k <- dim(q)[3] - 1
+  #############################
+  # Checking parameters k
+  #############################
   
-  hik <- apply(X = q, MARGIN = c(1, 3), sum)
-  Hik <- t(apply(X = hik, MARGIN = 1, cumsum))
-  
-  H <- array(data = 0, dim = c(nrow(q), ncol(q), k + 1))
-  
-  for (j in 1:(k + 1)) {
-    H[, , j] <- diag(Hik[, j])
+  if (!is.numeric(k)) {
+    stop("'k' must be a positive integer")
   }
   
-  return(H)
-}
-
-
-#' Method to compute the value of \eqn{\psi}
-#' 
-#' @description Method to compute the value of \eqn{\psi}
-#'   (See equation (3.16) p.53).
-#' 
-#' @param q An array giving the values of the kernel for a giving time horizon 
-#'   \eqn{[0, \dots, k]} (This kernel `q` is the output of the method `getKernel` 
-#'   or `.get.qy`).
-#' @return An array giving the value of \eqn{\psi(k)} at each time between 0 
-#'   and `k`.
-#' 
-#' @noRd
-#' 
-.get.psi <- function(q) {
-  
-  k <- dim(q)[3] - 1
-  
-  psi <- array(data = 0, dim = c(nrow(q), ncol(q), k + 1)) # (S, S, k + 1)
-  psi[, , 1] <- diag(x = 1, nrow = nrow(q), ncol = ncol(q)) # k = 0
-  
-  for (j in 1:k) {
-    
-    psi[, , j + 1] <-
-      -Reduce('+', lapply(
-        X = 0:(j - 1),
-        FUN = function(l)
-          psi[, , l + 1] %*% (-q[, , j - l + 1])
-      ))
+  if ((!((k >= 0) & ((k %% 1) == 0)))) {
+    stop("'k' must be a positive integer")
   }
   
-  return(psi)
+  #############################
+  # Checking parameters upstates
+  #############################
+  
+  if (!(is.vector(upstates) & (length(unique(upstates)) == length(upstates)))) {
+    stop("The subset of state space 'upstates' is not a vector of unique elements")
+  }
+  
+  if (!all(upstates %in% x$states)) {
+    stop("Every element of 'upstates' must be in 'states' ('upstates' is a subet of 'states')")
+  }
+  
+  qy <- .get.qy(x = x, k = k, upstates = upstates)
+  
+  return(qy)
   
 }
 
 
-#' Method to compute the value of \eqn{P}
-#' 
-#' @description Method to compute the value of \eqn{P} 
-#'   (See equation (3.33) p.59).
-#' 
-#' @param x An object of class `smm`.
-#' @param k A positive integer giving the time horizon.
-#' @param states Vector giving the states for which the mean sojourn time 
-#'   should be computed. `states` is a subset of \eqn{E}.
-#' @param var Logical. If `TRUE` the asymptotic variance is computed.
-#' @param klim Optional. The time horizon used to approximate the series in the 
-#'   computation of the mean sojourn times vector \eqn{m} (cf. 
-#'   [meanSojournTimes][meanSojournTimes] function) for the asymptotic 
-#'   variance.
-#' @return An array giving the value of \eqn{P_{i,j}(k)} at each time between 0
-#'   and `k` if `var = FALSE`. If `var = TRUE`, a list containing the 
-#'   following components:
-#'   \itemize{
-#'    \item{x: }{an array giving the value of \eqn{P_{ij}(k)} at each time 
-#'      between 0 and `k`;}
-#'    \item{sigma2: }{an array giving the asymptotic variance of the estimator 
-#'      \eqn{\sigma_{P}^{2}(i, j, k)}.}
-#'  }
-#'  
-#' @noRd
-#' 
+# Method to compute the value of \eqn{P}
 .get.P <- function(x, k, states = x$states, var = FALSE, klim = 10000) {
   
   ###########################################################
@@ -154,7 +98,7 @@ is.smm <- function(x) {
   H1 <- H[which(x$states %in% states), which(x$states %in% states), , drop = FALSE]
   B <- array(data = diag(nrow(H1)), dim = dim(H1)) - H1
   
-  p <- matrixConvolution(psi, B)
+  p <- C_matrixConvolution(psi, B)
   
   
   ###########################################################
@@ -180,20 +124,60 @@ is.smm <- function(x) {
 }
 
 
-#' Method to compute the value of \eqn{P_{Y}}
-#' 
-#' @description Method to compute the value of \eqn{P_{Y}}
-#'   (See Proposition 5.1 p.105-106).
-#' 
-#' @param x An object of class `smm`.
-#' @param k A positive integer giving the time horizon.
-#' @param states Vector giving the states for which the mean sojourn time 
-#'   should be computed. `states` is a subset of \eqn{E}.
-#' @return An array giving the value of \eqn{P_{Y}(k)} at each time between 0
-#'   and `k`.
-#' 
-#' @noRd
-#' 
+# Method to compute the value of \eqn{P}
+#' @export
+get.P <- function(x, k, states = x$states, var = FALSE, klim = 10000) {
+  
+  #############################
+  # Checking parameters k
+  #############################
+  
+  if (!is.numeric(k)) {
+    stop("'k' must be a positive integer")
+  }
+  
+  if ((!((k >= 0) & ((k %% 1) == 0)))) {
+    stop("'k' must be a positive integer")
+  }
+  
+  #############################
+  # Checking parameters states
+  #############################
+  
+  if (!(is.vector(states) & (length(unique(states)) == length(states)))) {
+    stop("The subset of state space 'states' is not a vector of unique elements")
+  }
+  
+  if (!all(states %in% x$states)) {
+    stop("Every element of 'states' must be in 'x$states'")
+  }
+  
+  #############################
+  # Checking parameters var
+  #############################
+  
+  if (!is.logical(var)) {
+    stop("'var' must be equal to TRUE or FALSE")
+  }
+  
+  #############################
+  # checking parameters klim
+  #############################
+  
+  if (!is.null(klim)) {
+    if (!((klim > 0) & ((klim %% 1) == 0))) {
+      stop("'klim' must be a strictly positive integer")
+    }
+  }
+  
+  P <- .get.P(x = x, k = k, states = states, var = var, klim = klim)
+  
+  return(P)
+  
+}
+
+
+# Method to compute the value of \eqn{P_{Y}}
 .get.Py <- function(x, k, upstates = x$states) {
   
   ###########################################################
@@ -207,13 +191,48 @@ is.smm <- function(x) {
   H <- .get.H(q = qy)
   B <- array(data = diag(nrow(H)), dim = dim(H)) - H
   
-  p <- matrixConvolution(psi, B)
+  p <- C_matrixConvolution(psi, B)
   
   return(p)
   
 }
 
 
+# Method to compute the value of \eqn{P_{Y}}
+#' @export
+get.Py <- function(x, k, upstates = x$states) {
+  
+  #############################
+  # Checking parameters k
+  #############################
+  
+  if (!is.numeric(k)) {
+    stop("'k' must be a positive integer")
+  }
+  
+  if ((!((k >= 0) & ((k %% 1) == 0)))) {
+    stop("'k' must be a positive integer")
+  }
+  
+  #############################
+  # Checking parameters upstates
+  #############################
+  
+  if (!(is.vector(upstates) & (length(unique(upstates)) == length(upstates)))) {
+    stop("The subset of state space 'upstates' is not a vector of unique elements")
+  }
+  
+  if (!all(upstates %in% x$states)) {
+    stop("Every element of 'upstates' must be in 'states' ('upstates' is a subet of 'states')")
+  }
+  
+  Py <- .get.Py(x = x, k = k, upstates = upstates)
+  
+  return(Py)
+  
+}
+
+
 #' @export
 meanSojournTimes.smm <- function(x, states = x$states, klim = 10000) {
   
@@ -291,7 +310,7 @@ reliability.smm <- function(x, k, upstates = x$states, level = 0.95, klim = 1000
   }
   
   #############################
-  # Checking parameter klim
+  # Checking parameters klim
   #############################
   
   if (!is.null(klim)) {
@@ -381,7 +400,7 @@ maintainability.smm <- function(x, k, upstates = x$states, level = 0.95, klim =
   }
   
   #############################
-  # Checking parameter klim
+  # Checking parameters klim
   #############################
   
   if (!is.null(klim)) {
@@ -440,7 +459,7 @@ availability.smm <- function(x, k, upstates = x$states, level = 0.95, klim = 100
   }
   
   #############################
-  # Checking parameter klim
+  # checking parameters klim
   #############################
   
   if (!is.null(klim)) {
@@ -595,7 +614,7 @@ mttf.smm <- function(x, upstates = x$states, level = 0.95, klim = 10000) {
   }
   
   #############################
-  # Checking parameter klim
+  # checking parameters klim
   #############################
   
   if (!is.null(klim)) {
