@@ -95,6 +95,13 @@
 #'                                type.sojourn = "fj", distr = nparam.matrix)
 #' 
 #' semimarkov
+#'
+#' @testexamples
+#' expect_true(all(semimarkov$init - vect.init == 0))
+#' expect_true(all(semimarkov$ptrans - pij == 0))
+#' expect_true(is.smm(semimarkov))
+#' expect_false(is.smmparametric(semimarkov))
+#' expect_true(is.smmnonparametric(semimarkov))
 smmnonparametric <- function(states, init, ptrans, type.sojourn = c("fij", "fi", "fj", "f"), 
                              distr, cens.beg = FALSE, cens.end = FALSE) {
   
@@ -272,9 +279,59 @@ is.smmnonparametric <- function(x) {
 }
 
 
+# Method to get the sojourn time distribution f
+.get.f.smmnonparametric <- function(x, k) {
+  
+  if (k <= x$kmax) {
+    end <- k
+  } else {
+    end <- x$kmax
+  }
+  
+  s <- x$s
+  
+  if (x$type.sojourn == "fij") {
+    f <- array(data = 0, dim = c(s, s, k))
+    f[, , 1:end] <- x$distr[, , 1:end]
+  } else if (x$type.sojourn == "fi" | x$type.sojourn == "fj") {
+    f <- matrix(data = 0, nrow = s, ncol = k)
+    f[, 1:end] <- x$distr[, 1:end]
+  } else if (x$type.sojourn == "f") {
+    f <- rep.int(x = 0, times = k)
+    f[1:end] <- x$distr[1:end]
+  }
+  
+  return(f)
+  
+}
+
+
+# Method to get the sojourn time distribution f
+#' @export
+get.f.smmnonparametric <- function(x, k) {
+  
+  #############################
+  # Checking parameters k
+  #############################
+  
+  if (!is.numeric(k)) {
+    stop("'k' must be a strictly positive integer")
+  }
+  
+  if ((!((k > 0) & ((k %% 1) == 0)))) {
+    stop("'k' must be a strictly positive integer")
+  }
+  
+  f <- .get.f.smmnonparametric(x = x, k = k)
+  
+  return(f)
+  
+}
+
+
 # Method to get the number of parameters
 # (useful for the computation of criteria such as AIC and BIC)
-.getKpar.smmnonparametric <- function(x) {
+.get.Kpar.smmnonparametric <- function(x) {
   
   s <- x$s
   kmax <- x$kmax
@@ -294,6 +351,17 @@ is.smmnonparametric <- function(x) {
 }
 
 
+# Method to get the number of parameters
+# (useful for the computation of criteria such as AIC and BIC)
+#' @export
+get.Kpar.smmnonparametric <- function(x) {
+  
+  kpar <- .get.Kpar.smmnonparametric(x)
+  
+  return(kpar)
+}
+
+
 #' Log-likelihood Function
 #' 
 #' @description Computation of the log-likelihood for a semi-Markov model
@@ -303,7 +371,7 @@ is.smmnonparametric <- function(x) {
 #' 
 #' @noRd
 #' 
-.loglik.smmnonparametric <- function(x, processes) {
+.logLik.smmnonparametric <- function(x, processes) {
   
   kmax <- processes$kmax
   type.sojourn <- x$type.sojourn
@@ -325,7 +393,7 @@ is.smmnonparametric <- function(x) {
     
     # Contribution of the initial distribution and 
     # the transition matrix to the log-likelihood
-    loglik <- sum(Nstarti[maskNstarti] * log(init[maskNstarti])) +
+    logLik <- sum(Nstarti[maskNstarti] * log(init[maskNstarti])) +
       sum(Nij[maskNij] * log(pij[maskNij]))
     
     
@@ -335,28 +403,28 @@ is.smmnonparametric <- function(x) {
       Nijk <- processes$counting$Nijk
       maskNijk <- Nijk != 0 & x$distr != 0
       
-      loglik <- loglik + sum(Nijk[maskNijk] * log(x$distr[maskNijk]))
+      logLik <- logLik + sum(Nijk[maskNijk] * log(x$distr[maskNijk]))
       
     } else if (type.sojourn == "fi") {
       
       Nik <- processes$counting$Nik
       maskNik <- Nik != 0 & x$distr != 0
       
-      loglik <- loglik + sum(Nik[maskNik] * log(x$distr[maskNik]))
+      logLik <- logLik + sum(Nik[maskNik] * log(x$distr[maskNik]))
       
     } else if (type.sojourn == "fj") {
       
       Njk <- processes$counting$Njk
       maskNjk <- Njk != 0 & x$distr != 0
       
-      loglik <- loglik + sum(Njk[maskNjk] * log(x$distr[maskNjk]))
+      logLik <- logLik + sum(Njk[maskNjk] * log(x$distr[maskNjk]))
       
     } else {
       
       Nk <- processes$counting$Nk
       maskNk <- Nk != 0 & x$distr != 0
       
-      loglik <- loglik + sum(Nk[maskNk] * log(x$distr[maskNk]))
+      logLik <- logLik + sum(Nk[maskNk] * log(x$distr[maskNk]))
       
     }
     
@@ -392,12 +460,12 @@ is.smmnonparametric <- function(x) {
     
     maskNiub <- Niub != 0 & piujv != 0
     
-    loglik <- sum(Nstarti * log(init)) +
+    logLik <- sum(Nstarti * log(init)) +
       sum(Niub[maskNiub] * log(piujv[maskNiub]))
     
   }
   
-  return(loglik)
+  return(logLik)
   
 }
 
@@ -415,15 +483,16 @@ is.smmnonparametric <- function(x) {
 #' 
 #' @export
 #' 
-aic.smmnonparametric <- function(x, sequences) {
+AIC.smmnonparametric <- function(object, ...) {
   
-  loglik <- loglik(x, sequences)
+  sequences = list(...)[1]
+  logLik <- logLik(object, sequences)
   
-  kpar <- .getKpar(x)
+  kpar <- .get.Kpar(object)
   
-  aic <- -2 * loglik + 2 * kpar
+  AIC <- -2 * logLik + 2 * kpar
   
-  return(aic)
+  return(AIC)
   
 }
 
@@ -441,17 +510,18 @@ aic.smmnonparametric <- function(x, sequences) {
 #' 
 #' @export
 #' 
-bic.smmnonparametric <- function(x, sequences) {
+BIC.smmnonparametric <- function(object, ...) {
   
-  loglik <- loglik(x, sequences)
+  sequences = list(...)[1]
+  logLik <- logLik(object, sequences)
   
-  kpar <- .getKpar(x)
+  kpar <- .get.Kpar(object)
   
   n <- sum(sapply(sequences, length))
   
-  bic <- -2 * loglik + log(n) * kpar
+  BIC <- -2 * logLik + log(n) * kpar
   
-  return(bic)
+  return(BIC)
   
 }
 
@@ -564,29 +634,30 @@ getKernel.smmnonparametric <- function(x, k, var = FALSE, klim = 10000) {
 #' 
 #' @export
 #' 
-loglik.smmnonparametric <- function(x, sequences) {
+logLik.smmnonparametric <- function(object, ...) {
   
   #############################
   # Checking parameters sequences and states
   #############################
   
+  sequences = list(...)[1]
   if (!(is.list(sequences) & all(sapply(sequences, class) %in% c("character", "numeric")))) {
     stop("The parameter 'sequences' should be a list of vectors")
   }
   
-  if (!all(unique(unlist(sequences)) %in% x$states)) {
-    stop("Some states in the list of observed sequences 'sequences' are not in the state space given by the model 'x'")
+  if (!all(unique(unlist(sequences)) %in% object$states)) {
+    stop("Some states in the list of observed sequences 'sequences' are not in the state space given by the model 'object'")
   }
   
-  processes <- processesSemiMarkov(sequences = sequences, states = x$states, verbose = FALSE)
+  processes <- processesSemiMarkov(sequences = sequences, states = object$states, verbose = FALSE)
   
-  if (!(processes$kmax == x$kmax)) {
-    stop("kmax of the given sequences is different from the kmax of the estimated model 'x'")
+  if (!(processes$kmax == object$kmax)) {
+    stop("kmax of the given sequences is different from the kmax of the estimated model 'object'")
   }
   
-  loglik <- .loglik.smmnonparametric(x = x, processes = processes)
+  logLik <- .logLik.smmnonparametric(x = object, processes = processes)
   
-  return(loglik)
+  return(logLik)
   
 }
 
