@@ -138,7 +138,14 @@
 #'                             type.sojourn = "fij", distr = distr.matrix, 
 #'                             param = param.array)
 #' semimarkov
-#' 
+#'
+#' @testexamples
+#' expect_true(all(semimarkov$init - vect.init == 0))
+#' expect_true(all(semimarkov$ptrans - pij == 0))
+#' expect_true(is.smm(semimarkov))
+#' expect_true(is.smmparametric(semimarkov))
+#' expect_false(is.smmnonparametric(semimarkov))
+#'
 smmparametric <- function(states, init, ptrans, type.sojourn = c("fij", "fi", "fj", "f"), 
                           distr, param, cens.beg = FALSE, cens.end = FALSE) {
   
@@ -248,7 +255,7 @@ smmparametric <- function(states, init, ptrans, type.sojourn = c("fij", "fi", "f
     for (i in 1:s) {
       for (j in 1:s) {
         if (i != j & !is.na(distr[i, j])) {
-          checking <- checkParameter(distr[i, j], param[i, j, ])
+          checking <- .checkParameters(distr[i, j], param[i, j, ])
           if (length(checking)) {
             allChecking <- c(allChecking, paste0("-Transition (i = \"", states[i], "\" to j = \"", states[j], "\"): ", checking))
           }
@@ -278,7 +285,7 @@ smmparametric <- function(states, init, ptrans, type.sojourn = c("fij", "fi", "f
     
     allChecking <- c()
     for (i in 1:s) {
-      checking <- checkParameter(distr[i], param[i, ])
+      checking <- .checkParameters(distr[i], param[i, ])
       if (length(checking)) {
         allChecking <- c(allChecking, paste0("-State ", ifelse(type.sojourn == "fi", "i", "j"), " = \"", states[i], "\": ", checking))
       }
@@ -304,7 +311,7 @@ smmparametric <- function(states, init, ptrans, type.sojourn = c("fij", "fi", "f
       stop("'param' must be a vector of length 2 since 'type.sojourn == \"f\"'")
     }
     
-    checking <- checkParameter(distr, param)
+    checking <- .checkParameters(distr, param)
     if (length(checking) != 0) {
       stop("Bad parameter specifications :\n", checking)
     }
@@ -510,6 +517,29 @@ is.smmparametric <- function(x) {
 }
 
 
+# Method to get the sojourn time distribution f
+#' @export
+get.f.smmparametric <- function(x, k) {
+   
+  #############################
+  # Checking parameters k
+  #############################
+  
+  if (!is.numeric(k)) {
+    stop("'k' must be a strictly positive integer")
+  }
+  
+  if ((!((k > 0) & ((k %% 1) == 0)))) {
+    stop("'k' must be a strictly positive integer")
+  }
+  
+  f <- .get.f.smmparametric(x = x, k = k)
+  
+  return(f)
+  
+}
+
+
 # Method to get the survival/reliability function Fbar
 # (useful to compute the contribution to the likelihood when censoring)
 .get.Fbar.smmparametric <- function(x, k) {
@@ -530,7 +560,7 @@ is.smmparametric <- function(x) {
 
 # Method to get the number of parameters
 # (useful for the computation of criteria such as AIC and BIC)
-.getKpar.smmparametric <- function(x) {
+.get.Kpar.smmparametric <- function(x) {
   
   distr <- x$distr
   
@@ -546,6 +576,17 @@ is.smmparametric <- function(x) {
 }
 
 
+# Method to get the number of parameters
+# (useful for the computation of criteria such as AIC and BIC)
+#' @export
+get.Kpar.smmparametric <- function(x) {
+  
+  kpar <- .get.Kpar.smmparametric(x)
+  
+  return(kpar)
+}
+
+
 #' Log-likelihood Function
 #' 
 #' @description Computation of the log-likelihood for a semi-Markov model
@@ -555,7 +596,7 @@ is.smmparametric <- function(x) {
 #' 
 #' @noRd
 #' 
-.loglik.smmparametric <- function(x, processes) {
+.logLik.smmparametric <- function(x, processes) {
   
   kmax <- processes$kmax
   type.sojourn <- x$type.sojourn
@@ -583,7 +624,7 @@ is.smmparametric <- function(x) {
     maskNijk <- Nijk != 0 & f != 0
     
     # Uncensored log-likelihood
-    loglik <- sum(Nstarti[maskNstarti] * log(init[maskNstarti])) +
+    logLik <- sum(Nstarti[maskNstarti] * log(init[maskNstarti])) +
       sum(Nij[maskNij] * log(pij[maskNij])) +
       sum(Nijk[maskNijk] * log(f[maskNijk]))
     
@@ -601,7 +642,7 @@ is.smmparametric <- function(x) {
       Neik <- processes$counting$Neik
       maskNeik <- Neik != 0 & Fbarj != 0
       
-      loglik <- loglik + (1 * cens.beg) * sum(Nbijk[maskNbijk] * log(Fbar[maskNbijk])) +
+      logLik <- logLik + (1 * cens.beg) * sum(Nbijk[maskNbijk] * log(Fbar[maskNbijk])) +
         (1 * cens.end) * sum(Neik[maskNeik] * log(Fbarj[maskNeik]))
       
     }
@@ -612,7 +653,7 @@ is.smmparametric <- function(x) {
     maskNik <- Nik != 0 & f != 0
     
     # Uncensored log-likelihood
-    loglik <- sum(Nstarti[maskNstarti] * log(init[maskNstarti])) +
+    logLik <- sum(Nstarti[maskNstarti] * log(init[maskNstarti])) +
       sum(Nij[maskNij] * log(pij[maskNij])) +
       sum(Nik[maskNik] * log(f[maskNik]))
     
@@ -627,7 +668,7 @@ is.smmparametric <- function(x) {
       Neik <- processes$counting$Neik
       maskNeik <- Neik != 0 & Fbar != 0
       
-      loglik <- loglik + (1 * cens.beg) * sum(Nbik[maskNbik] * log(Fbar[maskNbik])) +
+      logLik <- logLik + (1 * cens.beg) * sum(Nbik[maskNbik] * log(Fbar[maskNbik])) +
         (1 * cens.end) * sum(Neik[maskNeik] * log(Fbar[maskNeik]))
       
     }
@@ -638,7 +679,7 @@ is.smmparametric <- function(x) {
     maskNjk <- Njk != 0 & f != 0
     
     # Uncensored log-likelihood
-    loglik <- sum(Nstarti[maskNstarti] * log(init[maskNstarti])) +
+    logLik <- sum(Nstarti[maskNstarti] * log(init[maskNstarti])) +
       sum(Nij[maskNij] * log(pij[maskNij])) +
       sum(Njk[maskNjk] * log(f[maskNjk]))
     
@@ -656,7 +697,7 @@ is.smmparametric <- function(x) {
       Neik <- processes$counting$Neik
       maskNeik <- Neik != 0 & Fbar != 0
       
-      loglik <- loglik + (1 * cens.beg) * sum(Nbjk[maskNbjk] * log(Fbar[maskNbjk])) +
+      logLik <- logLik + (1 * cens.beg) * sum(Nbjk[maskNbjk] * log(Fbar[maskNbjk])) +
         (1 * cens.end) * sum(Neik[maskNeik] * log(Fbarj[maskNeik]))
       
     }
@@ -667,7 +708,7 @@ is.smmparametric <- function(x) {
     maskNk <- Nk != 0 & f != 0
     
     # Uncensored log-likelihood
-    loglik <- sum(Nstarti[maskNstarti] * log(init[maskNstarti])) +
+    logLik <- sum(Nstarti[maskNstarti] * log(init[maskNstarti])) +
       sum(Nij[maskNij] * log(pij[maskNij])) +
       sum(Nk[maskNk] * log(f[maskNk]))
     
@@ -682,14 +723,14 @@ is.smmparametric <- function(x) {
       Nek <- processes$counting$Nek
       maskNek <- Nek != 0 & Fbar != 0
       
-      loglik <- loglik + (1 * cens.beg) * sum(Nbk[maskNbk] * log(Fbar[maskNbk])) +
+      logLik <- logLik + (1 * cens.beg) * sum(Nbk[maskNbk] * log(Fbar[maskNbk])) +
         (1 * cens.end) * sum(Nek[maskNek] * log(Fbar[maskNek]))
       
     }
     
   }
   
-  return(loglik)
+  return(logLik)
   
 }
 
@@ -707,15 +748,16 @@ is.smmparametric <- function(x) {
 #' 
 #' @export
 #' 
-aic.smmparametric <- function(x, sequences) {
+AIC.smmparametric <- function(object, ...) {
+
+  sequences = list(...)[1]
+  logLik <- logLik(object, sequences)
   
-  loglik <- loglik(x, sequences)
+  kpar <- .get.Kpar(object)
   
-  kpar <- .getKpar(x)
+  AIC <- -2 * logLik + 2 * kpar
   
-  aic <- -2 * loglik + 2 * kpar
-  
-  return(aic)
+  return(AIC)
   
 }
 
@@ -733,17 +775,18 @@ aic.smmparametric <- function(x, sequences) {
 #' 
 #' @export
 #' 
-bic.smmparametric <- function(x, sequences) {
+BIC.smmparametric <- function(object, ...) {
   
-  loglik <- loglik(x, sequences)
+  sequences = list(...)[1]
+  logLik <- logLik(object, sequences)
   
-  kpar <- .getKpar(x)
+  kpar <- .get.Kpar(object)
   
   n <- sum(sapply(sequences, length))
   
-  bic <- -2 * loglik + log(n) * kpar
+  BIC <- -2 * logLik + log(n) * kpar
   
-  return(bic)
+  return(BIC)
   
 }
 
@@ -844,24 +887,25 @@ getKernel.smmparametric <- function(x, k, var = FALSE, klim = 10000) {
 #' 
 #' @export
 #' 
-loglik.smmparametric <- function(x, sequences) {
+logLik.smmparametric <- function(object, ...) {
   
   #############################
   # Checking parameters sequences and states
   #############################
-  
+
+  sequences = list(...)[1]
   if (!(is.list(sequences) & all(sapply(sequences, class) %in% c("character", "numeric")))) {
     stop("The parameter 'sequences' should be a list of vectors")
   }
   
-  if (!all(unique(unlist(sequences)) %in% x$states)) {
-    stop("Some states in the list of observed sequences 'sequences' are not in the state space given by the model 'x'")
+  if (!all(unique(unlist(sequences)) %in% object$states)) {
+    stop("Some states in the list of observed sequences 'sequences' are not in the state space given by the model 'object'")
   }
   
-  processes <- processesSemiMarkov(sequences = sequences, states = x$states, verbose = FALSE)
-  loglik <- .loglik.smmparametric(x = x, processes = processes)
+  processes <- processesSemiMarkov(sequences = sequences, states = object$states, verbose = FALSE)
+  logLik <- .logLik.smmparametric(x = object, processes = processes)
   
-  return(loglik)
+  return(logLik)
   
 }
 
